PgDoubleColumn<TableType> class

Represents a column of type double in a table.

It handles the conversion from and to JSON for you.

Inheritance

Constructors

PgDoubleColumn(String name)
Represents a column of type double in a table.

Properties

filterPattern String
The filter pattern to use when filtering with this column.
finalinherited
fromJson double Function(double jsonValue)
The function used to convert a JSON value to a ValueType.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the column in the postgres table.
finalinherited
queryPattern String
The query pattern to use when querying for this column.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJson double Function(double jsonValue)
The function used to convert a ValueType to a JSON value.
finalinherited

Methods

call(double value) PgValue<TableType, double, double>
Creates a PgValue from the provided value of the type ValueType.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited