PgMaybeSingleModifier<TableType> class

Retrieves only one row from the result if there is one.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
previousModifier PgModifier<TableType, PgJsonList, dynamic>?
The modifier that was applied before this one.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited