PgMaybeUTCDateTimeColumn<TableType> class
Represents a column that can be null of type DateTime (timestamp with time zone) in a table.
For a timestamp without time zone, use PgMaybeDateTimeColumn.
The difference between PgMaybeDateTimeColumn and PgMaybeUTCDateTimeColumn is that PgMaybeUTCDateTimeColumn converts the DateTime to UTC before converting it to JSON where as PgMaybeDateTimeColumn does not.
It handles the conversion from and to JSON for you.
Constructors
- PgMaybeUTCDateTimeColumn(String name)
- Represents a column of type DateTime (timestamp with time zone) in a table.
Properties
- filterPattern → String
-
The filter pattern to use when filtering with this column.
finalinherited
- fromJson → DateTime? Function(String? jsonValue)
-
The function used to convert a JSON value to a
ValueType.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the column in the postgres table.
finalinherited
- queryPattern → String
-
The query pattern to use when querying for this column.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toJson → String? Function(DateTime? value)
-
The function used to convert a
ValueTypeto a JSON value.finalinherited
Methods
-
call(
DateTime? value) → PgValue< TableType, DateTime?, String?> -
Creates a PgValue from the provided
valueof the typeValueType.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited