PgTableHere class
An annotation that marks a class as a PgTable for which an upsert should be generated.
Constructors
- PgTableHere()
-
An annotation that marks a class as a PgTable for which an upsert should
be generated.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited