PgValue<TableType, ValueType, JsonValueType> class

Represents the value of a column in a table.

TableType is used to provide type safety. Objects that require a value will only allow values of the provided TableType.

Properties

columnName String
The name of the column this value is for.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJson → JsonValueType Function()
Converts the value to a json object.
final
value → ValueType
The value of the column.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited